@@ -1,6 +1,6 @@
 ;;; Character set conversions
 
-;; Copyright (C) 2004, 2005 Brailcom, o.p.s.
+;; Copyright (C) 2004, 2005, 2006 Brailcom, o.p.s.
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -18,7 +18,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+;; Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
 
 (require 'fileio)
@@ -26,8 +26,9 @@
 
 (define (recode string from to)
   (with-temp-file-data (tmpfile string)
-    (system (format nil "recode -f %s..%s %s" from to tmpfile))
-    (read-file tmpfile)))
+    (with-temp-file out-tmpfile
+      (system (format nil "iconv -c -f %s -t %s -o %s %s" from to out-tmpfile tmpfile))
+      (read-file out-tmpfile))))
 
 (define (recode-utf8->current string)
   (let ((coding (current-voice-coding)))
