@@ -18,7 +18,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+;; Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
 ;; speak: supported
 ;; lexicon: ignored (no reasonable specification of the element)
@@ -39,6 +39,7 @@
 ;; desc: ignored (no reasonable use here known)
 
 
+(require 'duration)
 (require_module 'rxp)
 
 (require 'prosody-param)
@@ -234,29 +235,28 @@
   ((next-func) utt))
 
 ;; Breaks: Adjust silence durations.
-(Param.wrap Duration_Method ssml-duration-method
-  (lambda (utt)
-    ((next-value) utt)
-    (let ((token (utt.relation utt 'Token)))
-      (if (item.has_feat token 'ssml-break)
-          (let ((length (item.feat token 'ssml-break))
-                (starting-token token))
-            (set! token (item.next token))
-            (while (and token (not (item.daughtern token)))
-              (when (item.has_feat token 'ssml-break)
-                (set! length (+ length (item.feat token 'ssml-break))))
-              (set! token (item.next token)))
-            (while (and starting-token (and (not item.daughtern starting-token)))
-              (set! starting-token (item.prev starting-token)))
-            (when starting-token
-              (let* ((seg find_last_seg (item.daughtern starting-token))
-                     (silence (and seg (item.next seg))))
-                (when silence
-                  ;; The final step remains unimplemented for now.
-                  ;; We should adjust features of all the following segments here.
-                  (item.set_feat silence 'ssml-duration length)))))
-          (set! token (item.next token))))
-    utt))
+(define-wrapper (Duration utt) ssml-duration
+  ((next-func) utt)
+  (let ((token (utt.relation utt 'Token)))
+    (if (and token (item.has_feat token 'ssml-break))
+        (let ((length (item.feat token 'ssml-break))
+              (starting-token token))
+          (set! token (item.next token))
+          (while (and token (not (item.daughtern token)))
+            (when (item.has_feat token 'ssml-break)
+              (set! length (+ length (item.feat token 'ssml-break))))
+            (set! token (item.next token)))
+          (while (and starting-token (and (not item.daughtern starting-token)))
+            (set! starting-token (item.prev starting-token)))
+          (when starting-token
+            (let* ((seg find_last_seg (item.daughtern starting-token))
+                   (silence (and seg (item.next seg))))
+              (when silence
+                ;; The final step remains unimplemented for now.
+                ;; We should adjust features of all the following segments here.
+                (item.set_feat silence 'ssml-duration length)))))
+        (set! token (item.next token))))
+  utt)
 
 
 ;;; Markup handlers
@@ -496,9 +496,19 @@
           (token.punctuation "")
           (token.prepunctuation "")
           (token.whitespace ""))
-    (ssml-parse-xml ssml-text))
+    (ssml-parse-xml (ssml-fix-text ssml-text)))
   (set! ssml-parsed (reverse ssml-parsed)))
 
+(define (ssml-fix-text text)
+  ;; Work around Festival XML parsing bug
+  (let ((pieces '()))
+    (while (string-matches text ".*\\\\.*")
+      (push (string-before text "\\") pieces)
+      (push "\\\\" pieces)
+      (set! text (string-after text "\\")))
+    (push text pieces)
+    (apply string-append (reverse pieces))))
+
 (define (ssml-say ssml-text)
   (ssml-parse ssml-text)
   (ssml-speak-chunks))
