@@ -1,6 +1,6 @@
 ;;; Tokenization and utterance chunking
 
-;; Copyright (C) 2004, 2005 Brailcom, o.p.s.
+;; Copyright (C) 2004, 2005, 2006 Brailcom, o.p.s.
 
 ;; Author: Milan Zamazal <pdm@brailcom.org>
 
@@ -18,7 +18,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
+;; Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
 
 (require 'tts)
@@ -50,8 +50,7 @@
          (r-punc (lambda (c) (member_string c l-punc)))
          (r-prepunctuation (lambda (c) (member_string c l-prepunctuation)))
          (r-name (lambda (c)
-                   (not
-                    (or (r-whitespace c) (r-punc c) (r-prepunctuation c)))))
+                   (not (or (r-whitespace c) (r-punc c)))))
          (name "")
          (whitespace "")
          (punc "")
